==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fi\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  "Käyttäjä"
 ,"Käyttäjät"

]
, "Groups"
: "Ryhmät"

, "Roles"
: "Roolit"

, "Applications"
: "Ohjelmat"

, "Containers"
: ""

, "Shared Tags"
: ""

, "Customfields"
: ""

, "Computers"
: "Tietokoneet"

, "Access Log, Access Logs"
: [
  "Kirjautumisloki"
 ,"Kirjautumislokit"

]
, "Server Information"
: "Palvelimen tiedot"

, "ActiveSync Devices"
: ""

, "Admin"
: "Ylläpitäjä"

, "Refresh"
: "Päivitä"

, "Name"
: "Nimi"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  "Tietokone"
 ,"Tietokoneet"

]
, "Default Addressbook for new contacts and groups"
: "Oletus osoitekirja uusille yhteystiedoille ja ryhmille"

, "Group, Groups"
: [
  "Ryhmä"
 ,"Ryhmät"

]
, "Application, Applications"
: [
  "Ohjelma"
 ,"Ohjelmat"

]
, "Config, Configs"
: [
  ""
 ,""

]
, "Configs"
: ""

, "Please wait"
: "Odota hetki"

, "Updating Memberships"
: ""

, "Failed"
: "Epäonnistui"

, "Could not save group."
: ""

, "Errors"
: "Virheet"

, "Please fix the errors noted."
: "Korjaa löytyneet virheet."

, "Group Name"
: "Ryhmän nimi"

, "Description"
: "Kuvaus"

, "Visibility"
: "Näkyvyys"

, "Display in addressbook"
: "Näytä osoitekirjassa"

, "Hide from addressbook"
: "Älä näytä osoitekirjassa"

, "Saved in Addressbook"
: "Tallennettu osoitekirjaan"

, "Group Members"
: "Ryhmän jäsenet"

, "Transferring {0}..."
: "Siirretään {0}..."

, "Add new group"
: "Lisää uusi ryhmä"

, "Edit Group \"{0}\""
: "Muokkaa ryhmää \"{0}\""

, "Enable Application"
: "Aktivoi ohjelma"

, "Disable Application"
: "Poista ohjelma käytöstä"

, "Settings"
: "Asetukset"

, "{0} Settings"
: "{0} Asetukset"

, "enable application"
: "Ota ohjelma käyttöön"

, "disable application"
: "Poista ohjelma käytöstä"

, "settings"
: "asetukset"

, "Search:"
: "Hae:"

, "disabled"
: "pois käytöstä"

, "enabled"
: "käytössä"

, "unknown status ({0})"
: "tuntematon tila ({0})"

, "Displaying application {0} - {1} of {2}"
: "Näytetään ohjelmat {0} - {1} - {2}"

, "No applications to display"
: "Ei ohjelmia näytettäväksi"

, "Order"
: "Järjestys"

, "Status"
: "Tila"

, "Version"
: "Versio"

, "Confirm"
: "Vahvista"

, "Do you really want to delete the selected groups?"
: "Haluatko poistaa valitut ryhmät?"

, "Deleting group(s)..."
: "Poistetaan ryhmiä..."

, "Some error occurred while trying to delete the group."
: "Ryhmien poistossa havaittu virheitä."

, "Add Group"
: "Lisää ryhmä"

, "Edit Group"
: "Muokkaa ryhmää"

, "Delete Group"
: "Poista ryhmä"

, "Displaying groups {0} - {1} of {2}"
: "Näytetään ryhmät {0} - {1} - {2}"

, "No groups to display"
: "Ei ryhmiä"

, "ID"
: "Tunnus"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: "Tietokoneen nimi"

, "IP Address"
: "IP Osoite"

, "Login Time"
: "Kirjautumisaika"

, "Logout Time"
: "Ulos kirjautumisaika"

, "Client Type"
: "Asiakas tyyppi"

, "Session ID"
: "Yhteyden tunnus"

, "Login Name"
: "Kirjautumis nimi"

, "Result"
: "Tulokset"

, "user blocked"
: "käyttäjä estetty"

, "password expired"
: "salasana umpeutunut"

, "user disabled"
: "käyttäjä poistettu"

, "invalid password"
: "virheellinen salasana"

, "ambiguous username"
: ""

, "user not found"
: "käyttäjää ei löydy"

, "failure"
: "virhe"

, "success"
: "onnistui"

, "Could not save role."
: "Roolin tallennus ei onnistunut."

, "Deleting role..."
: "Poistetaan rooli..."

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: "Oikeudet"

, "Members"
: "Jäsenet"

, "Role Name"
: "Roolin nimi"

, "Role"
: "Rooli"

, "Add New Role"
: "Lisää uusi rooli"

, "Edit Role \"{0}\""
: ""

, "Container Name"
: ""

, "Type"
: "Tyyppi"

, "Container Order"
: ""

, "Container, Containers"
: [
  ""
 ,""

]
, "Model"
: "Malli"

, "personal"
: "henkilökohtainen"

, "shared"
: "jaettu"

, "Color"
: "Väri"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Huomautus käytäjälle"

, "Do you really want to delete the selected roles?"
: ""

, "Deleting role(s)..."
: ""

, "Add Role"
: "Lisää rooli"

, "Edit Role"
: "Muokkaa roolia"

, "Delete Role"
: "Poista rooli"

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: ""

, "Do you really want to delete the selected tags?"
: ""

, "Deleting tag(s)..."
: ""

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: ""

, "Usage:&#160;"
: ""

, "Label"
: ""

, "Value"
: "Arvo"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  "Muokattava kenttä"
 ,"Muokattavat kentät"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "Peruuta"

, "OK"
: "Ok"

, "Configure store"
: ""

, "Custom field definition"
: "Muokattavan kentän kuvaus"

, "Text"
: "Teksti"

, "Textarea"
: ""

, "Number"
: "Numero"

, "Date"
: "Päivä"

, "DateTime"
: "PäiväAika"

, "Time"
: "Aika"

, "Boolean"
: "Boolean"

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: "Pituus"

, "Required"
: "Vaaditaan"

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: "Aktivoi käyttäjätili"

, "Disable Account"
: "Poista käyttäjätili käytöstä"

, "Reset Password"
: "Nollaa salasana"

, "Reset Pin"
: ""

, "Display name"
: "Näyttönimi"

, "Login name"
: "Kirjautumisnimi"

, "Last name"
: "Sukunimi"

, "First name"
: "Etunimi"

, "Email"
: "Sähköpostiosoite"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: ""

, "Last login at"
: "Viimeksi kirjautunut"

, "Last login from"
: "Viimeksi kirjautunut "

, "Password changed"
: "Salasanan muuttaminen"

, "Expires"
: "Päättynyt"

, "Set new password"
: "Aseta uusi salasana"

, "Please enter the new password:"
: "Kirjoita uusi salasana: "

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: "Käyttäjät"

, "Samba User, Samba Users"
: [
  "Samba käyttäjä"
 ,"Samba käyttäjät"

]
, "Email User, Email Users"
: [
  "Sähköposti käyttäjä"
 ,"Sähköposti käyttäjät"

]
, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: ""

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Logon Time"
: "Kirjautumisaika"

, "never logged in"
: "ei koskaan kirjautunut sisään"

, "Home Path"
: "Kotipolku"

, "Logoff Time"
: "Uloskirjautumisaika"

, "never logged off"
: "ei koskaan kirjautunut ulos"

, "Profile Path"
: "Profiilin polku"

, "Password Last Set"
: "Salasana asetettu viimeksi"

, "never"
: "ei koskaan"

, "Logon Script"
: ""

, "Password Can Change"
: "Salasana voidaan vaihtaa"

, "not set"
: "ei asetettu"

, "Password Must Change"
: "Salasana on vaihdettava"

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: "Tila"

, "no quota set"
: "tilaa ei asetettu"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Nykyinen sähköpostilaatikon koko"

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "Tiedot"

, "Last Login"
: "Edellinen kirjautuminen"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: ""

, "Add an alias address..."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: ""

, "Email Forward"
: "Sähköpostin uudelleen ohjaus"

, "Add a forward address..."
: "Lisää osoite johon sähköpostit ohjataan..."

, "Forward Only"
: "Uudelleen ohjaus ainoastaan"

, "Password confirmation"
: "Salasanan vahvistaminen"

, "Repeat password"
: "Toista salasana"

, "Ok"
: "Ok"

, "Account"
: "Käyttäjätili"

, "Password"
: "Salasana"

, "expired"
: "päättynyt"

, "blocked"
: "estetty"

, "Invalid Status"
: "Virheellinen tila"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: "ei tiedossa"

, "Password set"
: ""

, "User groups"
: "Käyttäjä ryhmät"

, "User roles"
: ""

, "Fileserver"
: "Tiedostopalvelin"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: ""

, "Context"
: ""

, "Account Rights"
: ""

, "View"
: ""

, "Use"
: ""

, "Tag Name"
: ""

, "Tag"
: ""

, "Add New Tag"
: ""

, "Edit Tag \"{0}\""
: ""

, "Default IMAP user settings"
: "Oletus IMAP käyttäjä asetukset"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "hallitse kirjautumislokia"

, "delete access log entries"
: "poista kirjautumisloki tiedot"

, "manage accounts"
: "hallitse käyttäjätilejä"

, "add and edit users and groups, add group members, change user passwords"
: "lisää ja muokkaa käyttäjiä, ryhmiä ja ryhmien jäseniä sekä muuta salasanoja"

, "manage applications"
: "hallitse sovelluksia"

, "enable and disable applications, edit application settings"
: "ota käyttöön ja poista käytöstä ohjelmia sekä muokkaa ohjelmien asetuksia"

, "manage roles"
: "hallitse rooleja"

, "add and edit roles, add new members to roles, add application rights to roles"
: "lisää ja muokkaa rooleja ja uusia jäseniä rooleissa, ohjelmissa ja oikeuksia niissä"

, "manage shared tags"
: ""

, "add, delete and edit shared tags"
: ""

, "manage computers"
: "hallitse tietokoneita"

, "add, delete and edit (samba) computers"
: "lisää, poista ja muokkaa (samba) tietokoneita"

, "manage containers"
: "hallitse tallustiloja"

, "add, delete and edit containers and manage container grants"
: "lisää, poista ja muokkaa tallennustiloja sekä niiden oikeuksia"

, "manage customfields"
: ""

, "add and edit customfields"
: ""

, "view access log"
: "näytä kirjautumisloki"

, "view access log list"
: "näytä kirjautumisloki lista"

, "view accounts"
: "näytä käytäjätilit"

, "view accounts list and details"
: "näytä käyttäjätilit ja tiedot"

, "view applications"
: "näytä sovellukset"

, "view applications list and details"
: "näytä sovellukset lista ja tiedot"

, "view roles"
: "näytä roolit"

, "view roles list and details"
: "näytä roolit ja tiedot"

, "view computers"
: "näytä tietokoneet"

, "view computers list and details"
: "näytä tietokoneet lista ja tiedot"

, "view containers"
: "näytä tallennustilat"

, "view personal and shared containers"
: "näytä henkiläkohtaiset ja jaetut tallennustilat"

, "view customfields"
: ""

, "view customfields list"
: ""

, "view serverinfo"
: ""

, "view serverinfo list"
: ""

, "view quota usage"
: ""

, "Your container has been changed"
: "Tallennustilaasi on muokattu "

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Tallennustilaasi on muutettu %1$s %2$sHuom: %3$s"

, "Could not save tag without (view-)rights"
: ""

, "User"
: "Käyttäjä"

, "Access Log"
: "Kirjautumisloki"

, "Computer"
: "Tietokone"

, "Group"
: "Ryhmä"

, "Application"
: "Ohjelma"

, "Config"
: ""

, "Container"
: ""

, "Customfield"
: "Muokattava kenttä"

, "Samba User"
: "Samba käyttäjä"

, "Email User"
: "Sähköposti käyttäjä"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Admin/js/Admin-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: "Aktivoi ohjelma"

, "Disable Application"
: "Poista ohjelma käytöstä"

, "Settings"
: "Asetukset"

, "{0} Settings"
: "{0} Asetukset"

, "Search:"
: "Hae:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Näytetään ohjelmat {0} - {1} - {2}"

, "No applications to display"
: "Ei ohjelmia näytettäväksi"

, "Order"
: "Järjestys"

, "Name"
: "Nimi"

, "Status"
: "Tila"

, "Version"
: "Versio"

, "Confirm"
: "Vahvista"

, "Do you really want to delete the selected groups?"
: "Haluatko poistaa valitut ryhmät?"

, "Deleting group(s)..."
: "Poistetaan ryhmiä..."

, "Failed"
: "Epäonnistui"

, "Some error occurred while trying to delete the group."
: "Ryhmien poistossa havaittu virheitä."

, "Add Group"
: "Lisää ryhmä"

, "Edit Group"
: "Muokkaa ryhmää"

, "Delete Group"
: "Poista ryhmä"

, "Displaying groups {0} - {1} of {2}"
: "Näytetään ryhmät {0} - {1} - {2}"

, "No groups to display"
: "Ei ryhmiä"

, "ID"
: "Tunnus"

, "E-mail"
: ""

, "Description"
: "Kuvaus"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Virheet"

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  "Ohjelma"
 ,"Ohjelmat"

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "Peruuta"

, "OK"
: "Ok"

, "Configure store"
: ""

, "Model"
: "Malli"

, "Custom field definition"
: "Muokattavan kentän kuvaus"

, "Text"
: "Teksti"

, "Textarea"
: ""

, "Number"
: "Numero"

, "Date"
: "Päivä"

, "DateTime"
: "PäiväAika"

, "Time"
: "Aika"

, "Boolean"
: "Boolean"

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: "Tyyppi"

, "Label"
: ""

, "Length"
: "Pituus"

, "Required"
: "Vaaditaan"

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Ryhmä"
 ,"Ryhmät"

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  "Muokattava kenttä"
 ,"Muokattavat kentät"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: "Arvo"

, "Default ({0})"
: ""

, "Computer Name"
: "Tietokoneen nimi"

, "Default Addressbook for new contacts and groups"
: "Oletus osoitekirja uusille yhteystiedoille ja ryhmille"

, "Please wait"
: "Odota hetki"

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Korjaa löytyneet virheet."

, "Allowed Contexts"
: ""

, "Context"
: ""

, "Account Rights"
: ""

, "View"
: ""

, "Use"
: ""

, "Tag Name"
: ""

, "Color"
: "Väri"

, "Transferring {0}..."
: "Siirretään {0}..."

, "Tag"
: ""

, "Add New Tag"
: ""

, "Edit Tag \"{0}\""
: ""

, "Do you really want to delete the selected tags?"
: ""

, "Deleting tag(s)..."
: ""

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: ""

, "Usage:&#160;"
: ""

, "Updating Memberships"
: ""

, "Could not save role."
: "Roolin tallennus ei onnistunut."

, "Deleting role..."
: "Poistetaan rooli..."

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: "Oikeudet"

, "Members"
: "Jäsenet"

, "Role Name"
: "Roolin nimi"

, "Role"
: "Rooli"

, "Add New Role"
: "Lisää uusi rooli"

, "Edit Role \"{0}\""
: ""

, "Do you really want to delete the selected roles?"
: ""

, "Deleting role(s)..."
: ""

, "Add Role"
: "Lisää rooli"

, "Edit Role"
: "Muokkaa roolia"

, "Delete Role"
: "Poista rooli"

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: ""

, "Access Log, Access Logs"
: [
  "Kirjautumisloki"
 ,"Kirjautumislokit"

]
, "Groups"
: "Ryhmät"

, "Applications"
: "Ohjelmat"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: ""

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Login Time"
: "Kirjautumisaika"

, "never logged in"
: "ei koskaan kirjautunut sisään"

, "Home Path"
: "Kotipolku"

, "Logout Time"
: "Ulos kirjautumisaika"

, "never logged off"
: "ei koskaan kirjautunut ulos"

, "Profile Path"
: "Profiilin polku"

, "Password Last Set"
: "Salasana asetettu viimeksi"

, "never"
: "ei koskaan"

, "Logon Script"
: ""

, "Password Can Change"
: "Salasana voidaan vaihtaa"

, "not set"
: "ei asetettu"

, "Password Must Change"
: "Salasana on vaihdettava"

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: "Tila"

, "no quota set"
: "tilaa ei asetettu"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Nykyinen sähköpostilaatikon koko"

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "Tiedot"

, "Last Login"
: "Edellinen kirjautuminen"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "Uudelleen ohjaus ainoastaan"

, "Password confirmation"
: "Salasanan vahvistaminen"

, "Repeat password"
: "Toista salasana"

, "Ok"
: "Ok"

, "Account"
: "Käyttäjätili"

, "First name"
: "Etunimi"

, "Last name"
: "Sukunimi"

, "Login name"
: "Kirjautumisnimi"

, "Password"
: "Salasana"

, "OpenID"
: ""

, "enabled"
: "käytössä"

, "disabled"
: "pois käytöstä"

, "expired"
: "päättynyt"

, "blocked"
: "estetty"

, "Invalid Status"
: "Virheellinen tila"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: "Päättynyt"

, "Visibility"
: "Näkyvyys"

, "Display in addressbook"
: "Näytä osoitekirjassa"

, "Hide from addressbook"
: "Älä näytä osoitekirjassa"

, "Saved in Addressbook"
: "Tallennettu osoitekirjaan"

, "Last login at"
: "Viimeksi kirjautunut"

, "don't know"
: "ei tiedossa"

, "Last login from"
: "Viimeksi kirjautunut "

, "Password set"
: ""

, "User groups"
: "Käyttäjä ryhmät"

, "User roles"
: ""

, "Fileserver"
: "Tiedostopalvelin"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "Käyttäjä"
 ,"Käyttäjät"

]
, "Users"
: "Käyttäjät"

, "Samba User, Samba Users"
: [
  "Samba käyttäjä"
 ,"Samba käyttäjät"

]
, "Email User, Email Users"
: [
  "Sähköposti käyttäjä"
 ,"Sähköposti käyttäjät"

]
, "Enable Account"
: "Aktivoi käyttäjätili"

, "Disable Account"
: "Poista käyttäjätili käytöstä"

, "Reset Password"
: "Nollaa salasana"

, "Reset Pin"
: ""

, "Display name"
: "Näyttönimi"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Salasanan muuttaminen"

, "Set new password"
: "Aseta uusi salasana"

, "Please enter the new password:"
: "Kirjoita uusi salasana: "

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Ryhmän nimi"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Ryhmän jäsenet"

, "personal"
: "henkilökohtainen"

, "shared"
: "jaettu"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Huomautus käytäjälle"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  ""
 ,""

]
, "Container Name"
: ""

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Tietokone"
 ,"Tietokoneet"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Roolit"

, "Containers"
: ""

, "Shared Tags"
: ""

, "Customfields"
: ""

, "Computers"
: "Tietokoneet"

, "Server Information"
: "Palvelimen tiedot"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Ylläpitäjä"

, "Refresh"
: "Päivitä"

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "IP Osoite"

, "Client Type"
: "Asiakas tyyppi"

, "Session ID"
: "Yhteyden tunnus"

, "Login Name"
: "Kirjautumis nimi"

, "Result"
: "Tulokset"

, "user blocked"
: "käyttäjä estetty"

, "password expired"
: "salasana umpeutunut"

, "user disabled"
: "käyttäjä poistettu"

, "invalid password"
: "virheellinen salasana"

, "ambiguous username"
: ""

, "user not found"
: "käyttäjää ei löydy"

, "failure"
: "virhe"

, "success"
: "onnistui"

, "Default IMAP user settings"
: "Oletus IMAP käyttäjä asetukset"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Tallennustilaasi on muokattu "

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Tallennustilaasi on muutettu %1$s %2$sHuom: %3$s"

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""




































, "Application"
: "Ohjelma"

, "Group"
: "Ryhmä"

, "Customfield"
: "Muokattava kenttä"

, "Config"
: ""

, "Access Log"
: "Kirjautumisloki"

, "User"
: "Käyttäjä"

, "Samba User"
: "Samba käyttäjä"

, "Email User"
: "Sähköposti käyttäjä"

, "Container"
: ""

, "Computer"
: "Tietokone"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
